@@ -28,14 +28,16 @@
 
 using namespace Editor;
 
-MultipleChoiceWidget::MultipleChoiceWidget(QWidget *parent) : QWidget(parent)
+MultipleChoiceWidget::MultipleChoiceWidget(QWidget *parent)
+    : QWidget(parent)
+    , m_translation(Q_NULLPTR)
+    , m_choicesModel(new QStringListModel(this))
 {
     setupUi(this);
 
     connect(addChoiceButton, &QPushButton::clicked, this, &MultipleChoiceWidget::slotAddChoiceButton);
     connect(removeChoiceButton, &QPushButton::clicked, this, &MultipleChoiceWidget::slotRemoveChoiceButton);
 
-    m_choicesModel = new QStringListModel(this);
     multipleChoiceListView->setModel(m_choicesModel);
 
     connect(m_choicesModel, &QStringListModel::dataChanged, this, &MultipleChoiceWidget::slotDataChanged);
@@ -47,16 +49,20 @@ MultipleChoiceWidget::MultipleChoiceWidget(QWidget *parent) : QWidget(parent)
 }
 
 
-void MultipleChoiceWidget::slotDataChanged(const QModelIndex & topLeft, const QModelIndex & bottomRight)
+void MultipleChoiceWidget::slotDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight)
 {
     Q_UNUSED(topLeft)
     Q_UNUSED(bottomRight)
-    m_translation->multipleChoice() = m_choicesModel->stringList();
-    removeChoiceButton->setEnabled(m_translation && m_translation->multipleChoice().count() > 0);
+    if (m_translation) {
+        m_translation->setMultipleChoice(m_choicesModel->stringList());
+        removeChoiceButton->setEnabled(m_translation->getMultipleChoice().count() > 0);
+    } else {
+        removeChoiceButton->setEnabled(false);
+    }
 }
 
 
-void MultipleChoiceWidget::setTranslation(KEduVocExpression * entry, int translation)
+void MultipleChoiceWidget::setTranslation(KEduVocExpression *entry, int translation)
 {
     if (entry) {
         m_translation = entry->translation(translation);
@@ -66,12 +72,12 @@ void MultipleChoiceWidget::setTranslation(KEduVocExpression * entry, int transla
 
     if (m_translation) {
         setEnabled(true);
-        m_choicesModel->setStringList(m_translation->multipleChoice());
-        removeChoiceButton->setEnabled(m_translation->multipleChoice().count() > 0);
+        m_choicesModel->setStringList(m_translation->getMultipleChoice());
+        removeChoiceButton->setEnabled(m_translation->getMultipleChoice().count() > 0);
     } else {
         setEnabled(false);
     }
-    removeChoiceButton->setEnabled(m_translation && m_translation->multipleChoice().count() > 0);
+    removeChoiceButton->setEnabled(m_translation && m_translation->getMultipleChoice().count() > 0);
 }
 
 
@@ -94,12 +100,16 @@ void MultipleChoiceWidget::slotRemoveChoiceButton()
     } else {
         m_choicesModel->removeRows(m_choicesModel->rowCount(QModelIndex()) - 1, 1, QModelIndex());
     }
-    m_translation->multipleChoice() = m_choicesModel->stringList();
-    removeChoiceButton->setEnabled(m_translation && m_translation->multipleChoice().count() > 0);
+    if (m_translation) {
+        m_translation->setMultipleChoice(m_choicesModel->stringList());
+        removeChoiceButton->setEnabled(m_translation->getMultipleChoice().count() > 0);
+    } else {
+        removeChoiceButton->setEnabled(false);
+    }
 }
 
 
-bool MultipleChoiceWidget::eventFilter(QObject * obj, QEvent * event)
+bool MultipleChoiceWidget::eventFilter(QObject *obj, QEvent *event)
 {
     if (obj == multipleChoiceListView) {
         if (event->type() == QEvent::DragEnter) {
