@@ -56,7 +56,7 @@ void Parley::callTranslateWord(const QString & word, const QString& fromLanguage
     emit translationFinished(word, fromLanguage, toLanguage);
 }
 
-void Parley::addTranslation(QString word, QString fromLanguage, QString toLanguage, QString translation)
+void Parley::addTranslation(const QString &word, const QString &fromLanguage, const QString &toLanguage, const QString &translation)
 {
     if (m_translator)
         m_translator->addTranslation(word, fromLanguage, toLanguage, translation);
@@ -68,12 +68,12 @@ QStringList Parley::locales()
     return QLocale().uiLanguages();
 }
 
-QString Parley::localeName(QString locale)
+QString Parley::localeName(const QString &locale)
 {
     return QLocale( locale ).nativeLanguageName( );
 }
 
-void Parley::open(QString filename)
+void Parley::open(const QString &filename)
 {
     QUrl url( QUrl::fromLocalFile(filename) );
     qDebug() << url;
@@ -105,7 +105,7 @@ QVariantList Parley::selectedEntries()
 //             Expression entry(expr);
 //             qDebug() << entry.translationTexts();
         QObject * obj = new Expression(expr);
-        entries << qVariantFromValue(obj);
+        entries << QVariant::fromValue(obj);
     }
 
     return entries;
@@ -134,7 +134,7 @@ QVariantList Parley::selectedTranslations()
 //             Translation transltion(tr);
 //             qDebug() << entry.translationTexts();
         QObject * obj = new Translation(tr);
-        translations << qVariantFromValue(obj);
+        translations << QVariant::fromValue(obj);
     }
 
     return translations;
